@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -- |
 -- Module      : Crypto.Hash.Algorithms
 -- License     : BSD-style
@@ -10,6 +11,10 @@
 module Crypto.Hash.Algorithms
     ( HashAlgorithm
     -- * hash algorithms
+    , Blake2s_256(..)
+    , Blake2sp_256(..)
+    , Blake2b_512(..)
+    , Blake2bp_512(..)
     , MD2(..)
     , MD4(..)
     , MD5(..)
@@ -22,10 +27,10 @@ module Crypto.Hash.Algorithms
     , SHA512t_256(..)
     , RIPEMD160(..)
     , Tiger(..)
-    , Kekkak_224(..)
-    , Kekkak_256(..)
-    , Kekkak_384(..)
-    , Kekkak_512(..)
+    , Keccak_224(..)
+    , Keccak_256(..)
+    , Keccak_384(..)
+    , Keccak_512(..)
     , SHA3_224(..)
     , SHA3_256(..)
     , SHA3_384(..)
@@ -40,6 +45,10 @@ module Crypto.Hash.Algorithms
     ) where
 
 import           Crypto.Hash.Types (HashAlgorithm)
+import           Crypto.Hash.Blake2s
+import           Crypto.Hash.Blake2sp
+import           Crypto.Hash.Blake2b
+import           Crypto.Hash.Blake2bp
 import           Crypto.Hash.MD2
 import           Crypto.Hash.MD4
 import           Crypto.Hash.MD5
@@ -50,7 +59,7 @@ import           Crypto.Hash.SHA384
 import           Crypto.Hash.SHA512
 import           Crypto.Hash.SHA512t
 import           Crypto.Hash.SHA3
-import           Crypto.Hash.Kekkak
+import           Crypto.Hash.Keccak
 import           Crypto.Hash.RIPEMD160
 import           Crypto.Hash.Tiger
 import           Crypto.Hash.Skein256
