@@ -14,7 +14,7 @@ module Crypto.MAC.Poly1305
     ( Ctx
     , State
     , Auth(..)
-
+    , authTag
     -- * Incremental MAC Functions
     , initialize -- :: State
     , update     -- :: State -> ByteString -> State
@@ -29,17 +29,25 @@ import           Foreign.C.Types
 import           Data.Word
 import           Crypto.Internal.ByteArray (ByteArrayAccess, ScrubbedBytes, Bytes)
 import qualified Crypto.Internal.ByteArray as B
+import           Crypto.Internal.DeepSeq
+import           Crypto.Error
 
 -- | Poly1305 State
 newtype State = State ScrubbedBytes
     deriving (ByteArrayAccess)
 
+-- | Poly1305 State. use State instead of Ctx
 type Ctx = State
 {-# DEPRECATED Ctx "use Poly1305 State instead" #-}
 
 -- | Poly1305 Auth
 newtype Auth = Auth Bytes
-    deriving (ByteArrayAccess)
+    deriving (ByteArrayAccess,NFData)
+
+authTag :: ByteArrayAccess b => b -> CryptoFailable Auth
+authTag b
+    | B.length b /= 16 = CryptoFailed $ CryptoError_AuthenticationTagSizeInvalid
+    | otherwise        = CryptoPassed $ Auth $ B.convert b
 
 instance Eq Auth where
     (Auth a1) == (Auth a2) = B.constEq a1 a2
@@ -56,10 +64,10 @@ foreign import ccall unsafe "cryptonite_poly1305.h cryptonite_poly1305_finalize"
 -- | initialize a Poly1305 context
 initialize :: ByteArrayAccess key
            => key
-           -> State
+           -> CryptoFailable State
 initialize key
-    | B.length key /= 32 = error "Poly1305: key length expected 32 bytes"
-    | otherwise          = State $ B.allocAndFreeze 84 $ \ctxPtr ->
+    | B.length key /= 32 = CryptoFailed $ CryptoError_MacKeyInvalid
+    | otherwise          = CryptoPassed $ State $ B.allocAndFreeze 84 $ \ctxPtr ->
         B.withByteArray key $ \keyPtr ->
             c_poly1305_init (castPtr ctxPtr) keyPtr
 {-# NOINLINE initialize #-}
