@@ -15,6 +15,7 @@ module Crypto.PubKey.ECC.P256
     ( Scalar
     , Point
     -- * point arithmetic
+    , pointBase
     , pointAdd
     , pointMul
     , pointsMulVarTime
@@ -25,6 +26,7 @@ module Crypto.PubKey.ECC.P256
     , pointToBinary
     , pointFromBinary
     -- * scalar arithmetic
+    , scalarGenerate
     , scalarZero
     , scalarIsZero
     , scalarAdd
@@ -48,6 +50,7 @@ import           Crypto.Internal.ByteArray
 import qualified Crypto.Internal.ByteArray as B
 import           Data.Memory.PtrMethods (memSet)
 import           Crypto.Error
+import           Crypto.Random
 import           Crypto.Number.Serialize.Internal (os2ip, i2ospOf)
 import qualified Crypto.Number.Serialize as S (os2ip, i2ospOf)
 
@@ -75,6 +78,12 @@ data P256X
 -- Point methods
 ------------------------------------------------------------------------
 
+-- | Get the base point for the P256 Curve
+pointBase :: Point
+pointBase =
+    case scalarFromInteger 1 of
+        CryptoPassed s  -> toPoint s
+        CryptoFailed _ -> error "pointBase: assumption failed"
 
 -- | Lift to curve a scalar
 --
@@ -119,6 +128,7 @@ pointIsValid p = unsafeDoIO $ withPoint p $ \px py -> do
     r <- ccryptonite_p256_is_valid_point px py
     return (r /= 0)
 
+-- | Convert a point to (x,y) Integers
 pointToIntegers :: Point -> (Integer, Integer)
 pointToIntegers p = unsafeDoIO $ withPoint p $ \px py ->
     allocTemp 32 (serialize (castPtr px) (castPtr py))
@@ -130,6 +140,7 @@ pointToIntegers p = unsafeDoIO $ withPoint p $ \px py ->
         y <- os2ip temp scalarSize
         return (x,y)
 
+-- | Convert from (x,y) Integers to a point
 pointFromIntegers :: (Integer, Integer) -> Point
 pointFromIntegers (x,y) = withNewPoint $ \dx dy ->
     allocTemp scalarSize (\temp -> fill temp (castPtr dx) x >> fill temp (castPtr dy) y)
@@ -146,11 +157,13 @@ pointFromIntegers (x,y) = withNewPoint $ \dx dy ->
         -- then fill dest with the P256 scalar from temp
         ccryptonite_p256_from_bin temp dest
 
+-- | Convert a point to a binary representation
 pointToBinary :: ByteArray ba => Point -> ba
 pointToBinary p = B.unsafeCreate pointSize $ \dst -> withPoint p $ \px py -> do
     ccryptonite_p256_to_bin (castPtr px) dst
     ccryptonite_p256_to_bin (castPtr py) (dst `plusPtr` 32)
 
+-- | Convert from binary to a point
 pointFromBinary :: ByteArrayAccess ba => ba -> CryptoFailable Point
 pointFromBinary ba
     | B.length ba /= pointSize = CryptoFailed $ CryptoError_PublicKeySizeInvalid
@@ -163,10 +176,20 @@ pointFromBinary ba
 -- Scalar methods
 ------------------------------------------------------------------------
 
+-- | Generate a randomly generated new scalar
+scalarGenerate :: MonadRandom randomly => randomly Scalar
+scalarGenerate = unwrap . scalarFromBinary . witness <$> getRandomBytes 32
+  where
+    unwrap (CryptoFailed _) = error "scalarGenerate: assumption failed"
+    unwrap (CryptoPassed s) = s
+    witness :: ScrubbedBytes -> ScrubbedBytes
+    witness = id
+
 -- | The scalar representing 0
 scalarZero :: Scalar
 scalarZero = withNewScalarFreeze $ \d -> ccryptonite_p256_init d
 
+-- | Check if the scalar is 0
 scalarIsZero :: Scalar -> Bool
 scalarIsZero s = unsafeDoIO $ withScalar s $ \d -> do
     result <- ccryptonite_p256_is_zero d
@@ -233,10 +256,12 @@ scalarToBinary s = B.unsafeCreate scalarSize $ \b -> withScalar s $ \p ->
     ccryptonite_p256_to_bin p b
 {-# NOINLINE scalarToBinary #-}
 
+-- | Convert from an Integer to a P256 Scalar
 scalarFromInteger :: Integer -> CryptoFailable Scalar
 scalarFromInteger i =
     maybe (CryptoFailed CryptoError_SecretKeySizeInvalid) scalarFromBinary (S.i2ospOf 32 i :: Maybe Bytes)
 
+-- | Convert from a P256 Scalar to an Integer
 scalarToInteger :: Scalar -> Integer
 scalarToInteger s = S.os2ip (scalarToBinary s :: Bytes)
 
