@@ -17,6 +17,7 @@ module Crypto.PubKey.ECC.Types
     , CurveBinary(..)
     , CurvePrime(..)
     , common_curve
+    , curveSizeBits
     , ecc_fx
     , ecc_p
     , CurveCommon(..)
@@ -27,6 +28,7 @@ module Crypto.PubKey.ECC.Types
 
 import           Data.Data
 import           Crypto.Internal.Imports
+import           Crypto.Number.Basic (numBits)
 
 -- | Define either a binary curve or a prime curve.
 data Curve = CurveF2m CurveBinary -- ^ 𝔽(2^m)
@@ -160,6 +162,10 @@ curvesOIDs =
     ]
 -}
 
+-- | get the size of the curve in bits
+curveSizeBits :: Curve -> Int
+curveSizeBits = numBits . ecc_n . common_curve
+
 -- | Get the curve definition associated with a recommended known curve name.
 getCurveByName :: CurveName -> Curve
 getCurveByName SEC_p112r1 = CurveFP  $ CurvePrime
