@@ -9,10 +9,13 @@ module Crypto.Random
     (
     -- * Deterministic instances
       ChaChaDRG
+    , SystemDRG
     -- * Deterministic Random class
+    , getSystemDRG
     , drgNew
     , drgNewTest
     , withDRG
+    , withRandomBytes
     , DRG(..)
     -- * Random abstraction
     , MonadRandom(..)
@@ -21,13 +24,15 @@ module Crypto.Random
 
 import Crypto.Random.Types
 import Crypto.Random.ChaChaDRG
-import Crypto.Random.Entropy
-import Data.ByteArray (ScrubbedBytes)
+import Crypto.Random.SystemDRG
+import Data.ByteArray (ByteArray, ScrubbedBytes)
 import Crypto.Internal.Imports
 
 -- | Create a new DRG from system entropy
-drgNew :: IO ChaChaDRG
-drgNew = initialize <$> (getEntropy 40 :: IO ScrubbedBytes)
+drgNew :: MonadRandom randomly => randomly ChaChaDRG
+drgNew = do
+    b <- getRandomBytes 40
+    return $ initialize (b :: ScrubbedBytes)
 
 -- | Create a new DRG from 5 Word64.
 --
@@ -38,3 +43,10 @@ drgNew = initialize <$> (getEntropy 40 :: IO ScrubbedBytes)
 -- has been properly randomly generated.
 drgNewTest :: (Word64, Word64, Word64, Word64, Word64) -> ChaChaDRG
 drgNewTest = initializeWords
+
+-- | Generate @len random bytes and mapped the bytes to the function @f.
+--
+-- This is equivalent to use Control.Arrow 'first' with 'randomBytesGenerate'
+withRandomBytes :: (ByteArray ba, DRG g) => g -> Int -> (ba -> a) -> (a, g)
+withRandomBytes rng len f = (f bs, rng')
+  where (bs, rng') = randomBytesGenerate len rng
