@@ -4,6 +4,7 @@ module Main where
 import Imports
 
 import qualified Number
+import qualified BCrypt
 import qualified Hash
 import qualified Poly1305
 import qualified Salsa
@@ -24,10 +25,12 @@ import qualified KAT_RC4
 import qualified KAT_TripleDES
 -- misc --------------------------------
 import qualified KAT_AFIS
+import qualified Padding
 
 tests = testGroup "cryptonite"
     [ Number.tests
     , Hash.tests
+    , Padding.tests
     , testGroup "MAC"
         [ Poly1305.tests
         , KAT_HMAC.tests
@@ -38,6 +41,7 @@ tests = testGroup "cryptonite"
     , testGroup "KDF"
         [ KAT_PBKDF2.tests
         , KAT_Scrypt.tests
+        , BCrypt.tests
         ]
     , testGroup "block-cipher"
         [ KAT_AES.tests
